INSERT INTO crams_projectmemberstatus (code, status) VALUES ('M', 'Project member');
INSERT INTO crams_projectmemberstatus (code, status) VALUES ('I', 'Membership invited');
INSERT INTO crams_projectmemberstatus (code, status) VALUES ('R', 'Membership request');
INSERT INTO crams_projectmemberstatus (code, status) VALUES ('C', 'Invitation cancelled');
INSERT INTO crams_projectmemberstatus (code, status) VALUES ('E', 'Request rejected');
INSERT INTO crams_projectmemberstatus (code, status) VALUES ('V', 'Membership revoked');
INSERT INTO crams_projectmemberstatus (code, status) VALUES ('U', 'User role changed');
INSERT INTO crams_projectmemberstatus (code, status) VALUES ('L', 'Request cancelled');
INSERT INTO crams_projectmemberstatus (code, status) VALUES ('D', 'Invitation declined');