# Generated by Django 3.2 on 2021-07-06 06:32

from django.db import migrations, models

class Migration(migrations.Migration):

    dependencies = [
        ('crams', '0008_load_crams_lookups'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProjectMemberStatus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.CharField(max_length=50)),
                ('status', models.CharField(max_length=100)),
            ],
        ),
    ]


