-- noinspection SqlDialectInspectionForFile
-- noinspection SqlNoDataSourceInspectionForFile
INSERT INTO crams_seocode (id, code, description) VALUES (1,'810101','Air Force');
INSERT INTO crams_seocode (id, code, description) VALUES (2,'810102','Army');
INSERT INTO crams_seocode (id, code, description) VALUES (3,'810103','Command, Control and Communications');
INSERT INTO crams_seocode (id, code, description) VALUES (4,'810108','Navy');
INSERT INTO crams_seocode (id, code, description) VALUES (5,'810199','Defence not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (6,'820105','Softwood Plantations');
INSERT INTO crams_seocode (id, code, description) VALUES (7,'820204','Hops');
INSERT INTO crams_seocode (id, code, description) VALUES (8,'820206','Macadamias');
INSERT INTO crams_seocode (id, code, description) VALUES (9,'820207','Mushrooms and Truffles');
INSERT INTO crams_seocode (id, code, description) VALUES (10,'820212','Table Grapes');
INSERT INTO crams_seocode (id, code, description) VALUES (11,'820213','Tree Nuts (excl. Almonds and Macadamias)');
INSERT INTO crams_seocode (id, code, description) VALUES (12,'820214','Tropical Fruit');
INSERT INTO crams_seocode (id, code, description) VALUES (13,'820215','Vegetables');
INSERT INTO crams_seocode (id, code, description) VALUES (14,'820299','Horticultural Crops not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (15,'820301','Cotton');
INSERT INTO crams_seocode (id, code, description) VALUES (16,'820302','Essential Oil Crops (e.g. Tea Tree, Eucalyptus, Lavender, Peppermint, Boronia, Sandalwood)');
INSERT INTO crams_seocode (id, code, description) VALUES (17,'820303','Plant Extract Crops (e.g. Pyrethrum, Jojoba)');
INSERT INTO crams_seocode (id, code, description) VALUES (18,'820304','Sugar');
INSERT INTO crams_seocode (id, code, description) VALUES (19,'820305','Tobacco');
INSERT INTO crams_seocode (id, code, description) VALUES (20,'820306','Wine Grapes');
INSERT INTO crams_seocode (id, code, description) VALUES (21,'820399','Industrial Crops not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (22,'820401','Maize');
INSERT INTO crams_seocode (id, code, description) VALUES (23,'820402','Rice');
INSERT INTO crams_seocode (id, code, description) VALUES (24,'820403','Safflower Seed');
INSERT INTO crams_seocode (id, code, description) VALUES (25,'820404','Sorghum');
INSERT INTO crams_seocode (id, code, description) VALUES (26,'820499','Summer Grains and Oilseeds not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (27,'820501','Barley');
INSERT INTO crams_seocode (id, code, description) VALUES (28,'820502','Canola');
INSERT INTO crams_seocode (id, code, description) VALUES (29,'820503','Grain Legumes');
INSERT INTO crams_seocode (id, code, description) VALUES (30,'820504','Linseed');
INSERT INTO crams_seocode (id, code, description) VALUES (31,'820505','Lupins');
INSERT INTO crams_seocode (id, code, description) VALUES (32,'820506','Oats');
INSERT INTO crams_seocode (id, code, description) VALUES (33,'820507','Wheat');
INSERT INTO crams_seocode (id, code, description) VALUES (34,'820599','Winter Grains and Oilseeds not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (35,'820601','Cotton Lint and Cotton Seed');
INSERT INTO crams_seocode (id, code, description) VALUES (36,'820602','Fresh Fruits and Vegetables (Post Harvest)');
INSERT INTO crams_seocode (id, code, description) VALUES (37,'820603','Sugar Cane (Cut for Crushing)');
INSERT INTO crams_seocode (id, code, description) VALUES (38,'820604','Tobacco Leaf');
INSERT INTO crams_seocode (id, code, description) VALUES (39,'820605','Unprocessed Grains');
INSERT INTO crams_seocode (id, code, description) VALUES (40,'820606','Unprocessed Industrial Crops (excl. Sugar, Tobacco and Cotton)');
INSERT INTO crams_seocode (id, code, description) VALUES (41,'820607','Unprocessed Oilseeds');
INSERT INTO crams_seocode (id, code, description) VALUES (42,'820699','Harvesting and Packing of Plant Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (43,'829801','Management of Gaseous Waste from Plant Production (excl. Greenhouse Gases)');
INSERT INTO crams_seocode (id, code, description) VALUES (44,'829802','Management of Greenhouse Gas Emissions from Plant Production');
INSERT INTO crams_seocode (id, code, description) VALUES (45,'829803','Management of Liquid Waste from Plant Production (excl. Water)');
INSERT INTO crams_seocode (id, code, description) VALUES (46,'829804','Management of Solid Waste from Plant Production');
INSERT INTO crams_seocode (id, code, description) VALUES (47,'829805','Management of Water Consumption by Plant Production');
INSERT INTO crams_seocode (id, code, description) VALUES (48,'829899','Environmentally Sustainable Plant Production not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (49,'829901','Forest Product Traceability and Quality Assurance');
INSERT INTO crams_seocode (id, code, description) VALUES (50,'829902','Plant Product Traceability and Quality Assurance (excl. Forest Products)');
INSERT INTO crams_seocode (id, code, description) VALUES (51,'829999','Plant Production and Plant Primary Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (52,'830101','Aquaculture Crustaceans (excl. Rock Lobster and Prawns)');
INSERT INTO crams_seocode (id, code, description) VALUES (53,'830102','Aquaculture Fin Fish (excl. Tuna)');
INSERT INTO crams_seocode (id, code, description) VALUES (54,'830103','Aquaculture Molluscs (excl. Oysters)');
INSERT INTO crams_seocode (id, code, description) VALUES (55,'830104','Aquaculture Oysters');
INSERT INTO crams_seocode (id, code, description) VALUES (56,'830105','Aquaculture Prawns');
INSERT INTO crams_seocode (id, code, description) VALUES (57,'830106','Aquaculture Rock Lobster');
INSERT INTO crams_seocode (id, code, description) VALUES (58,'830107','Aquaculture Tuna');
INSERT INTO crams_seocode (id, code, description) VALUES (59,'830199','Fisheries - Aquaculture not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (60,'830201','Fisheries - Recreational');
INSERT INTO crams_seocode (id, code, description) VALUES (61,'830202','Wild Caught Crustaceans (excl. Rock Lobster and Prawns)');
INSERT INTO crams_seocode (id, code, description) VALUES (62,'830203','Wild Caught Edible Molluscs');
INSERT INTO crams_seocode (id, code, description) VALUES (63,'830207','Wild Caught Tuna');
INSERT INTO crams_seocode (id, code, description) VALUES (64,'830303','Deer');
INSERT INTO crams_seocode (id, code, description) VALUES (65,'830307','Minor Livestock (e.g. Alpacas, Ostriches, Crocodiles, Farmed Rabbits)');
INSERT INTO crams_seocode (id, code, description) VALUES (66,'830311','Sheep - Wool');
INSERT INTO crams_seocode (id, code, description) VALUES (67,'830403','Native and Residual Pastures');
INSERT INTO crams_seocode (id, code, description) VALUES (68,'830499','Pasture, Browse and Fodder Crops not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (69,'830502','Honey');
INSERT INTO crams_seocode (id, code, description) VALUES (70,'830505','Raw Wool');
INSERT INTO crams_seocode (id, code, description) VALUES (71,'839801','Management of Gaseous Waste from Animal Production (excl. Greenhouse Gases)');
INSERT INTO crams_seocode (id, code, description) VALUES (72,'839802','Management of Greenhouse Gas Emissions from Animal Production');
INSERT INTO crams_seocode (id, code, description) VALUES (73,'839803','Management of Liquid Waste from Animal Production (excl. Water)');
INSERT INTO crams_seocode (id, code, description) VALUES (74,'839804','Management of Solid Waste from Animal Production');
INSERT INTO crams_seocode (id, code, description) VALUES (75,'839805','Management of Water Consumption by Animal Production');
INSERT INTO crams_seocode (id, code, description) VALUES (76,'839899','Environmentally Sustainable Animal Production not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (77,'839901','Animal Welfare');
INSERT INTO crams_seocode (id, code, description) VALUES (78,'839902','Fish Product Traceability and Quality Assurance');
INSERT INTO crams_seocode (id, code, description) VALUES (79,'839903','Livestock Product Traceability and Quality Assurance');
INSERT INTO crams_seocode (id, code, description) VALUES (80,'839999','Animal Production and Animal Primary Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (81,'840101','Aluminium Ore Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (82,'840102','Copper Ore Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (83,'840103','Diamond Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (84,'840104','Iron Ore Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (85,'840105','Precious (Noble) Metal Ore Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (86,'840106','Stone and Clay Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (87,'840108','Zinc Ore Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (88,'840199','Mineral Exploration not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (89,'840201','Mining and Extraction of Aluminium Ores');
INSERT INTO crams_seocode (id, code, description) VALUES (90,'840202','Mining and Extraction of Copper Ores');
INSERT INTO crams_seocode (id, code, description) VALUES (91,'840203','Mining and Extraction of Diamonds');
INSERT INTO crams_seocode (id, code, description) VALUES (92,'840205','Mining and Extraction of Precious (Noble) Metal Ores ');
INSERT INTO crams_seocode (id, code, description) VALUES (93,'840206','Mining and Extraction of Stone and Clay');
INSERT INTO crams_seocode (id, code, description) VALUES (94,'840207','Mining and Extraction of Titanium Minerals, Zircon, and Rare Earth Metal Ores (e.g. Monazite)');
INSERT INTO crams_seocode (id, code, description) VALUES (95,'840208','Mining and Extraction of Zinc Ores');
INSERT INTO crams_seocode (id, code, description) VALUES (96,'840299','Primary Mining and Extraction of Mineral Resources not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (97,'840301','Alumina Production');
INSERT INTO crams_seocode (id, code, description) VALUES (98,'840302','Beneficiation of Bauxite and Aluminium Ores (excl. Alumina Production)');
INSERT INTO crams_seocode (id, code, description) VALUES (99,'840303','Beneficiation or Dressing of Iron Ores');
INSERT INTO crams_seocode (id, code, description) VALUES (100,'840304','Beneficiation or Dressing of Non-Metallic Minerals (incl. Diamonds)');
INSERT INTO crams_seocode (id, code, description) VALUES (101,'840305','Concentrating Processes of Base Metal Ores (excl. Aluminium and Iron Ores)');
INSERT INTO crams_seocode (id, code, description) VALUES (102,'840306','Production of Unrefined Precious Metal Ingots and Concentrates');
INSERT INTO crams_seocode (id, code, description) VALUES (103,'840399','First Stage Treatment of Ores and Minerals not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (104,'849801','Management of Gaseous Waste From Mineral Resource Activities (excl. Greenhouse Gases)');
INSERT INTO crams_seocode (id, code, description) VALUES (105,'849802','Management of Greenhouse Gas Emissions from Mineral Resource Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (106,'849805','Management of Water Consumption by Mineral Resource Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (107,'849899','Environmentally Sustainable Mineral Resource Activities not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (108,'849999','Mineral Resources (excl. Energy Resources) not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (109,'850101','Coal Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (110,'850102','Geothermal Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (111,'850103','Oil and Gas Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (112,'850105','Uranium Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (113,'850201','Coal Mining and Extraction');
INSERT INTO crams_seocode (id, code, description) VALUES (114,'850203','Oil and Gas Extraction');
INSERT INTO crams_seocode (id, code, description) VALUES (115,'850301','Hydrogen Production from Fossil Fuels');
INSERT INTO crams_seocode (id, code, description) VALUES (116,'850305','Preparation of Black Coal');
INSERT INTO crams_seocode (id, code, description) VALUES (117,'850309','Production of Biofuels (Biomass)');
INSERT INTO crams_seocode (id, code, description) VALUES (118,'850403','Nuclear Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (119,'850407','Transformation of Coal into Gaseous Fuels');
INSERT INTO crams_seocode (id, code, description) VALUES (120,'850499','Energy Transformation not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (121,'850503','Hydro-Electric Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (122,'850505','Solar-Thermal Electric Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (123,'850507','Tidal Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (124,'850601','Energy Services and Utilities');
INSERT INTO crams_seocode (id, code, description) VALUES (125,'850602','Energy Storage (excl. Hydrogen)');
INSERT INTO crams_seocode (id, code, description) VALUES (126,'850603','Energy Systems Analysis');
INSERT INTO crams_seocode (id, code, description) VALUES (127,'850604','Energy Transmission and Distribution (excl. Hydrogen)');
INSERT INTO crams_seocode (id, code, description) VALUES (128,'850605','Hydrogen Distribution');
INSERT INTO crams_seocode (id, code, description) VALUES (129,'850606','Hydrogen Storage');
INSERT INTO crams_seocode (id, code, description) VALUES (130,'850699','Energy Storage, Distribution and Supply not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (131,'850701','Commercial Energy Conservation and Efficiency');
INSERT INTO crams_seocode (id, code, description) VALUES (132,'850702','Energy Conservation and Efficiency in Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (133,'850704','Residential Energy Conservation and Efficiency');
INSERT INTO crams_seocode (id, code, description) VALUES (134,'850799','Energy Conservation and Efficiency not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (135,'859801','Management of Gaseous Waste from Energy Activities (excl. Greenhouse Gases)');
INSERT INTO crams_seocode (id, code, description) VALUES (136,'859802','Management of Greenhouse Gas Emissions from Electricity Generation');
INSERT INTO crams_seocode (id, code, description) VALUES (137,'859803','Management of Greenhouse Gas Emissions from Energy Activities (excl. Electricity Generation)');
INSERT INTO crams_seocode (id, code, description) VALUES (138,'859804','Management of Liquid Waste from Energy Activities (excl. Water)');
INSERT INTO crams_seocode (id, code, description) VALUES (139,'859805','Management of Solid Waste from Energy Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (140,'859806','Management of Water Consumption by Energy Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (141,'859899','Environmentally Sustainable Energy Activities not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (142,'860101','Bakery Products');
INSERT INTO crams_seocode (id, code, description) VALUES (143,'860102','Beverages (excl. Fruit Juices)');
INSERT INTO crams_seocode (id, code, description) VALUES (144,'860103','Carcass Meat (incl. Fish and Seafood)');
INSERT INTO crams_seocode (id, code, description) VALUES (145,'860104','Flour Mill and Cereal Food');
INSERT INTO crams_seocode (id, code, description) VALUES (146,'860105','Nutraceuticals and Functional foods');
INSERT INTO crams_seocode (id, code, description) VALUES (147,'860106','Oils and Fats (incl. Margarines)');
INSERT INTO crams_seocode (id, code, description) VALUES (148,'860107','Processed Fish and Seafood Products');
INSERT INTO crams_seocode (id, code, description) VALUES (149,'860108','Processed Fruit and Vegetable Products (incl. Fruit Juices)');
INSERT INTO crams_seocode (id, code, description) VALUES (150,'860111','Sugar and Confectionery Products');
INSERT INTO crams_seocode (id, code, description) VALUES (151,'860202','Casein');
INSERT INTO crams_seocode (id, code, description) VALUES (152,'860205','Whey');
INSERT INTO crams_seocode (id, code, description) VALUES (153,'860302','Organic Fertilisers');
INSERT INTO crams_seocode (id, code, description) VALUES (154,'860399','Processed Non-Food Agricultural Products (excl. Wood, Paper and Fibre) not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (155,'860403','Natural Fibres, Yarns and Fabrics');
INSERT INTO crams_seocode (id, code, description) VALUES (156,'860499','Leather Products, Fibre Processing and Textiles not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (157,'860501','Paper Products (incl. Coated Paper)');
INSERT INTO crams_seocode (id, code, description) VALUES (158,'860502','Printing and Publishing Processes');
INSERT INTO crams_seocode (id, code, description) VALUES (159,'860503','Pulp and Paper');
INSERT INTO crams_seocode (id, code, description) VALUES (160,'860504','Reconstituted Timber Products (e.g. Chipboard, Particleboard)');
INSERT INTO crams_seocode (id, code, description) VALUES (161,'860505','Wood Sawing and Veneer');
INSERT INTO crams_seocode (id, code, description) VALUES (162,'860599','Wood, Wood Products and Paper not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (163,'860601','Industrial Gases');
INSERT INTO crams_seocode (id, code, description) VALUES (164,'860602','Inorganic Industrial Chemicals');
INSERT INTO crams_seocode (id, code, description) VALUES (165,'860603','Lubricants');
INSERT INTO crams_seocode (id, code, description) VALUES (166,'860604','Organic Industrial Chemicals (excl. Resins, Rubber and Plastics)');
INSERT INTO crams_seocode (id, code, description) VALUES (167,'860605','Paints');
INSERT INTO crams_seocode (id, code, description) VALUES (168,'860606','Plastics in Primary Forms');
INSERT INTO crams_seocode (id, code, description) VALUES (169,'860607','Plastic Products (incl. Construction Materials)');
INSERT INTO crams_seocode (id, code, description) VALUES (170,'860609','Soaps and Cosmetics');
INSERT INTO crams_seocode (id, code, description) VALUES (171,'860608','Rubber and Synthetic Resins');
INSERT INTO crams_seocode (id, code, description) VALUES (172,'860701','Animal Protection Chemicals');
INSERT INTO crams_seocode (id, code, description) VALUES (173,'860702','Chemical Fertilisers');
INSERT INTO crams_seocode (id, code, description) VALUES (174,'860703','Crop Protection Chemicals');
INSERT INTO crams_seocode (id, code, description) VALUES (175,'860799','Agricultural Chemicals not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (176,'860801','Human Biological Preventatives (e.g. Vaccines)');
INSERT INTO crams_seocode (id, code, description) VALUES (177,'860802','Human Diagnostics');
INSERT INTO crams_seocode (id, code, description) VALUES (178,'860803','Human Pharmaceutical Treatments (e.g. Antibiotics)');
INSERT INTO crams_seocode (id, code, description) VALUES (179,'860899','Human Pharmaceutical Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (180,'860901','Veterinary Biological Preventatives (e.g. Vaccines)');
INSERT INTO crams_seocode (id, code, description) VALUES (181,'860902','Veterinary Diagnostics');
INSERT INTO crams_seocode (id, code, description) VALUES (182,'860903','Veterinary Pharmaceutical Treatments (e.g. Antibiotics)');
INSERT INTO crams_seocode (id, code, description) VALUES (183,'860999','Veterinary Pharmaceutical Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (184,'861001','Cement Products and Concrete Materials');
INSERT INTO crams_seocode (id, code, description) VALUES (185,'861002','Ceramics');
INSERT INTO crams_seocode (id, code, description) VALUES (186,'861003','Clay Products');
INSERT INTO crams_seocode (id, code, description) VALUES (187,'861004','Plaster and Plaster Products');
INSERT INTO crams_seocode (id, code, description) VALUES (188,'861005','Structural Glass and Glass Products');
INSERT INTO crams_seocode (id, code, description) VALUES (189,'861102','Basic Copper Products');
INSERT INTO crams_seocode (id, code, description) VALUES (190,'861103','Basic Iron and Steel Products');
INSERT INTO crams_seocode (id, code, description) VALUES (191,'861104','Basic Precious Metal Products');
INSERT INTO crams_seocode (id, code, description) VALUES (192,'861105','Basic Zinc Products');
INSERT INTO crams_seocode (id, code, description) VALUES (193,'861199','Basic Metal Products (incl. Smelting, Rolling, Drawing and Extruding) not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (194,'861201','Coated Metal and Metal-Coated Products');
INSERT INTO crams_seocode (id, code, description) VALUES (195,'861202','Machined Metal Products');
INSERT INTO crams_seocode (id, code, description) VALUES (196,'861203','Metal Castings');
INSERT INTO crams_seocode (id, code, description) VALUES (197,'861204','Semi-Finished Metal Products');
INSERT INTO crams_seocode (id, code, description) VALUES (198,'861205','Sheet Metal Products');
INSERT INTO crams_seocode (id, code, description) VALUES (199,'861206','Structural Metal Products');
INSERT INTO crams_seocode (id, code, description) VALUES (200,'861301','Aerospace Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (201,'861302','Automotive Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (202,'861303','Nautical Equipment (excl. Yachts)');
INSERT INTO crams_seocode (id, code, description) VALUES (203,'861305','Yachts');
INSERT INTO crams_seocode (id, code, description) VALUES (204,'861399','Transport Equipment not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (205,'861401','Agricultural Machinery and Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (206,'861402','Appliances and Electrical Machinery and Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (207,'861403','Industrial Machinery and Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (208,'861404','Mining Machinery and Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (209,'861499','Machinery and Equipment not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (210,'861501','Industrial Instruments');
INSERT INTO crams_seocode (id, code, description) VALUES (211,'861502','Medical Instruments');
INSERT INTO crams_seocode (id, code, description) VALUES (212,'861605','Processor Modules');
INSERT INTO crams_seocode (id, code, description) VALUES (213,'861699','Computer Hardware and Electronic Equipment not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (214,'869801','Management of Gaseous Waste from Manufacturing Activities (excl. Greenhouse Gases)');
INSERT INTO crams_seocode (id, code, description) VALUES (215,'869999','Manufacturing not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (216,'870201','Civil Construction Design');
INSERT INTO crams_seocode (id, code, description) VALUES (217,'870303','Polymeric Materials (e.g. Paints)');
INSERT INTO crams_seocode (id, code, description) VALUES (218,'870404','Residential Construction Processes');
INSERT INTO crams_seocode (id, code, description) VALUES (219,'870501','Civil Building Management and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (220,'870502','Commercial Building Management and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (221,'870503','Residential Building Management and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (222,'870599','Building Management and Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (223,'879801','Management of Gaseous Waste from Construction Activities (excl. Greenhouse Gases)');
INSERT INTO crams_seocode (id, code, description) VALUES (224,'879802','Management of Greenhouse Gas Emissions from Construction Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (225,'879803','Management of Liquid Waste from Construction Activities (excl. Water)');
INSERT INTO crams_seocode (id, code, description) VALUES (226,'879804','Management of Solid Waste from Construction Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (227,'879805','Management of Water Consumption by Construction Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (228,'879899','Environmentally Sustainable Construction not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (229,'879999','Construction not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (230,'880101','Rail Freight');
INSERT INTO crams_seocode (id, code, description) VALUES (231,'880102','Rail Infrastructure and Networks');
INSERT INTO crams_seocode (id, code, description) VALUES (232,'880103','Rail Passenger Movements');
INSERT INTO crams_seocode (id, code, description) VALUES (233,'880104','Rail Safety');
INSERT INTO crams_seocode (id, code, description) VALUES (234,'880105','Road Freight');
INSERT INTO crams_seocode (id, code, description) VALUES (235,'880106','Road Infrastructure and Networks');
INSERT INTO crams_seocode (id, code, description) VALUES (236,'880107','Road Passenger Movements (excl. Public Transport)');
INSERT INTO crams_seocode (id, code, description) VALUES (237,'880108','Road Public Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (238,'880109','Road Safety');
INSERT INTO crams_seocode (id, code, description) VALUES (239,'880199','Ground Transport not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (240,'880201','Coastal Sea Freight Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (241,'880202','International Sea Freight Transport (excl. Live Animal Transport)');
INSERT INTO crams_seocode (id, code, description) VALUES (242,'880204','Passenger Water Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (243,'880205','Port Infrastructure and Management');
INSERT INTO crams_seocode (id, code, description) VALUES (244,'880206','Water Safety');
INSERT INTO crams_seocode (id, code, description) VALUES (245,'880299','Water Transport not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (246,'880301','Air Freight');
INSERT INTO crams_seocode (id, code, description) VALUES (247,'880302','Air Passenger Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (248,'880303','Air Safety');
INSERT INTO crams_seocode (id, code, description) VALUES (249,'880304','Air Terminal Infrastructure and Management');
INSERT INTO crams_seocode (id, code, description) VALUES (250,'889801','Management of Gaseous Waste from Transport Activities (excl. Greenhouse Gases)');
INSERT INTO crams_seocode (id, code, description) VALUES (251,'889803','Management of Liquid Waste from Transport Activities (excl. Water)');
INSERT INTO crams_seocode (id, code, description) VALUES (252,'889804','Management of Noise and Vibration from Transport Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (253,'889805','Management of Solid Waste from Transport Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (254,'889806','Management of Water Consumption by Transport Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (255,'889901','Intermodal Materials Handling');
INSERT INTO crams_seocode (id, code, description) VALUES (256,'889904','Postal and Package Services (incl. Courier Services)');
INSERT INTO crams_seocode (id, code, description) VALUES (257,'889999','Transport not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (258,'890101','Fixed Line Data Networks and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (259,'890102','Fixed Line Telephone Networks and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (260,'890103','Mobile Data Networks and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (261,'890104','Mobile Telephone Networks and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (262,'890105','Satellite Communication Networks and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (263,'890106','Videoconference Services');
INSERT INTO crams_seocode (id, code, description) VALUES (264,'890199','Communication Networks and Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (265,'890202','Application Tools and System Utilities');
INSERT INTO crams_seocode (id, code, description) VALUES (266,'890204','Computer Time Leasing, Sharing and Renting Services');
INSERT INTO crams_seocode (id, code, description) VALUES (267,'890205','Information Processing Services (incl. Data Entry and Capture)');
INSERT INTO crams_seocode (id, code, description) VALUES (268,'890206','Internet Hosting Services (incl. Application Hosting Services)');
INSERT INTO crams_seocode (id, code, description) VALUES (269,'890299','Computer Software and Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (270,'890301','Electronic Information Storage and Retrieval Services');
INSERT INTO crams_seocode (id, code, description) VALUES (271,'890302','Library and Archival Services');
INSERT INTO crams_seocode (id, code, description) VALUES (272,'890303','News Collection Services');
INSERT INTO crams_seocode (id, code, description) VALUES (273,'890399','Information Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (274,'890401','Animation and Computer Generated Imagery Services');
INSERT INTO crams_seocode (id, code, description) VALUES (275,'890402','Film and Video Services (excl. Animation and Computer Generated Imagery)');
INSERT INTO crams_seocode (id, code, description) VALUES (276,'890403','Internet Broadcasting');
INSERT INTO crams_seocode (id, code, description) VALUES (277,'890404','Publishing and Print Services (incl. Internet Publishing)');
INSERT INTO crams_seocode (id, code, description) VALUES (278,'890405','Radio and Television Broadcasting');
INSERT INTO crams_seocode (id, code, description) VALUES (279,'890499','Media Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (280,'899801','Management of Greenhouse Gas Emissions from Information and Communication Services');
INSERT INTO crams_seocode (id, code, description) VALUES (281,'899802','Management of Solid Waste from Information and Communication Services');
INSERT INTO crams_seocode (id, code, description) VALUES (282,'899803','Management of Water Consumption by Information and Communication Services');
INSERT INTO crams_seocode (id, code, description) VALUES (283,'899899','Environmentally Sustainable Information and Communication Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (284,'899999','Information and Communication Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (285,'900101','Finance Services');
INSERT INTO crams_seocode (id, code, description) VALUES (286,'900102','Investment Services (excl. Superannuation)');
INSERT INTO crams_seocode (id, code, description) VALUES (287,'900103','Superannuation and Insurance Services');
INSERT INTO crams_seocode (id, code, description) VALUES (288,'900199','Financial Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (289,'900201','Administration and Business Support Services');
INSERT INTO crams_seocode (id, code, description) VALUES (290,'900202','Professional, Scientific and Technical Services');
INSERT INTO crams_seocode (id, code, description) VALUES (291,'900203','Property Services (incl. Security)');
INSERT INTO crams_seocode (id, code, description) VALUES (292,'900204','Wholesale and Retail Trade');
INSERT INTO crams_seocode (id, code, description) VALUES (293,'900299','Property, Business Support Services and Trade not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (294,'900301','Economic Issues in Tourism');
INSERT INTO crams_seocode (id, code, description) VALUES (295,'900302','Socio-Cultural Issues in Tourism');
INSERT INTO crams_seocode (id, code, description) VALUES (296,'900303','Tourism Infrastructure Development');
INSERT INTO crams_seocode (id, code, description) VALUES (297,'900399','Tourism not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (298,'900401','Waste Management Services');
INSERT INTO crams_seocode (id, code, description) VALUES (299,'900402','Waste Recycling Services');
INSERT INTO crams_seocode (id, code, description) VALUES (300,'900403','Water Recycling Services (incl. Sewage and Greywater)');
INSERT INTO crams_seocode (id, code, description) VALUES (301,'900404','Water Services and Utilities');
INSERT INTO crams_seocode (id, code, description) VALUES (302,'900499','Water and Waste Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (303,'909801','Management of Gaseous Waste from Commercial Services and Tourism (excl. Greenhouse Gases)');
INSERT INTO crams_seocode (id, code, description) VALUES (304,'909802','Management of Greenhouse Gas Emissions from Commercial Services and Tourism');
INSERT INTO crams_seocode (id, code, description) VALUES (305,'909803','Management of Liquid Waste from Commercial Services and Tourism (excl. Water)');
INSERT INTO crams_seocode (id, code, description) VALUES (306,'909804','Management of Solid Waste from Commercial Services and Tourism');
INSERT INTO crams_seocode (id, code, description) VALUES (307,'909805','Management of Water Consumption by Commercial Services and Tourism');
INSERT INTO crams_seocode (id, code, description) VALUES (308,'909901','Hospitality Services');
INSERT INTO crams_seocode (id, code, description) VALUES (309,'909902','Recreational Services');
INSERT INTO crams_seocode (id, code, description) VALUES (310,'909999','Commercial Services and Tourism not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (311,'910101','Balance of Payments');
INSERT INTO crams_seocode (id, code, description) VALUES (312,'910103','Economic Growth');
INSERT INTO crams_seocode (id, code, description) VALUES (313,'910105','Fiscal Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (314,'910106','Income Distribution');
INSERT INTO crams_seocode (id, code, description) VALUES (315,'910107','Macro Labour Market Issues');
INSERT INTO crams_seocode (id, code, description) VALUES (316,'910108','Monetary Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (317,'910110','Taxation');
INSERT INTO crams_seocode (id, code, description) VALUES (318,'910199','Macroeconomics not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (319,'910201','Consumption');
INSERT INTO crams_seocode (id, code, description) VALUES (320,'910203','Industrial Organisations');
INSERT INTO crams_seocode (id, code, description) VALUES (321,'910204','Industry Costs and Structure');
INSERT INTO crams_seocode (id, code, description) VALUES (322,'910206','Market-Based Mechanisms');
INSERT INTO crams_seocode (id, code, description) VALUES (323,'910209','Preference, Behaviour and Welfare');
INSERT INTO crams_seocode (id, code, description) VALUES (324,'910502','Defence Standards and Calibrations');
INSERT INTO crams_seocode (id, code, description) VALUES (325,'920110','Inherited Diseases (incl. Gene Therapy)');
INSERT INTO crams_seocode (id, code, description) VALUES (326,'920205','Health Education and Promotion');
INSERT INTO crams_seocode (id, code, description) VALUES (327,'920309','Pacific Peoples Health - Health System Performance (incl. Effectiveness of Interventions)');
INSERT INTO crams_seocode (id, code, description) VALUES (328,'920499','Public Health (excl. Specific Population Health) not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (329,'930202','Teacher and Instructor Development');
INSERT INTO crams_seocode (id, code, description) VALUES (330,'930203','Teaching and Instruction Technologies');
INSERT INTO crams_seocode (id, code, description) VALUES (331,'930301','Assessment and Evaluation of Curriculum');
INSERT INTO crams_seocode (id, code, description) VALUES (332,'930302','Syllabus and Curriculum Development');
INSERT INTO crams_seocode (id, code, description) VALUES (333,'930399','Curriculum not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (334,'930402','School/Institution Community and Environment');
INSERT INTO crams_seocode (id, code, description) VALUES (335,'930403','School/Institution Policies and Development');
INSERT INTO crams_seocode (id, code, description) VALUES (336,'930501','Education and Training Systems Policies and Development');
INSERT INTO crams_seocode (id, code, description) VALUES (337,'930503','Resourcing of Education and Training Systems');
INSERT INTO crams_seocode (id, code, description) VALUES (338,'930599','Education and Training Systems not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (339,'939901','Aboriginal and Torres Strait Islander Education');
INSERT INTO crams_seocode (id, code, description) VALUES (340,'939902','Education and Training Theory and Methodology');
INSERT INTO crams_seocode (id, code, description) VALUES (341,'939903','Equity and Access to Education');
INSERT INTO crams_seocode (id, code, description) VALUES (342,'939904','Gender Aspects of Education');
INSERT INTO crams_seocode (id, code, description) VALUES (343,'939905','Maori Education');
INSERT INTO crams_seocode (id, code, description) VALUES (344,'939906','Pacific Peoples Education');
INSERT INTO crams_seocode (id, code, description) VALUES (345,'939907','Special Needs Education');
INSERT INTO crams_seocode (id, code, description) VALUES (346,'939908','Workforce Transition and Employment');
INSERT INTO crams_seocode (id, code, description) VALUES (347,'939999','Education and Training not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (348,'940101','Ability and Disability');
INSERT INTO crams_seocode (id, code, description) VALUES (349,'940102','Aboriginal and Torres Strait Islander Development and Welfare');
INSERT INTO crams_seocode (id, code, description) VALUES (350,'940103','Ageing and Older People');
INSERT INTO crams_seocode (id, code, description) VALUES (351,'940104','Carers'' Development and Welfare');
INSERT INTO crams_seocode (id, code, description) VALUES (352,'940105','Children''s/Youth Services and Childcare');
INSERT INTO crams_seocode (id, code, description) VALUES (353,'940106','Citizenship and National Identity');
INSERT INTO crams_seocode (id, code, description) VALUES (354,'940107','Comparative Structure and Development of Community Services');
INSERT INTO crams_seocode (id, code, description) VALUES (355,'940108','Distribution of Income and Wealth');
INSERT INTO crams_seocode (id, code, description) VALUES (356,'940109','Employment Services');
INSERT INTO crams_seocode (id, code, description) VALUES (357,'940111','Ethnicity, Multiculturalism and Migrant Development and Welfare');
INSERT INTO crams_seocode (id, code, description) VALUES (358,'940116','Social Class and Inequalities');
INSERT INTO crams_seocode (id, code, description) VALUES (359,'940203','Political Systems');
INSERT INTO crams_seocode (id, code, description) VALUES (360,'940303','International Organisations');
INSERT INTO crams_seocode (id, code, description) VALUES (361,'940403','Criminal Justice');
INSERT INTO crams_seocode (id, code, description) VALUES (362,'940408','Rehabilitation and Correctional Services');
INSERT INTO crams_seocode (id, code, description) VALUES (363,'940504','Work and Family Responsibilities');
INSERT INTO crams_seocode (id, code, description) VALUES (364,'950102','Organised Sports');
INSERT INTO crams_seocode (id, code, description) VALUES (365,'950103','Recreation');
INSERT INTO crams_seocode (id, code, description) VALUES (366,'950105','The Performing Arts (incl. Theatre and Dance)');
INSERT INTO crams_seocode (id, code, description) VALUES (367,'950199','Arts and Leisure not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (368,'950202','Languages and Literacy');
INSERT INTO crams_seocode (id, code, description) VALUES (369,'950203','Languages and Literature');
INSERT INTO crams_seocode (id, code, description) VALUES (370,'950205','Visual Communication');
INSERT INTO crams_seocode (id, code, description) VALUES (371,'950299','Communication not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (372,'950301','_huatanga M_ori (M_ori Tradition)');
INSERT INTO crams_seocode (id, code, description) VALUES (373,'950302','Conserving Aboriginal and Torres Strait Islander Heritage');
INSERT INTO crams_seocode (id, code, description) VALUES (374,'950303','Conserving Collections and Movable Cultural Heritage');
INSERT INTO crams_seocode (id, code, description) VALUES (375,'950304','Conserving Intangible Cultural Heritage');
INSERT INTO crams_seocode (id, code, description) VALUES (376,'950305','Conserving Natural Heritage');
INSERT INTO crams_seocode (id, code, description) VALUES (377,'950306','Conserving Pacific Peoples Heritage');
INSERT INTO crams_seocode (id, code, description) VALUES (378,'950309','Taonga (M_ori Artefacts)');
INSERT INTO crams_seocode (id, code, description) VALUES (379,'950310','Tikanga M_ori (M_ori Customary Practices) ');
INSERT INTO crams_seocode (id, code, description) VALUES (380,'950402','Business Ethics');
INSERT INTO crams_seocode (id, code, description) VALUES (381,'950403','Environmental Ethics');
INSERT INTO crams_seocode (id, code, description) VALUES (382,'950404','Religion and Society');
INSERT INTO crams_seocode (id, code, description) VALUES (383,'950405','Religious Structures and Ritual');
INSERT INTO crams_seocode (id, code, description) VALUES (384,'950407','Social Ethics');
INSERT INTO crams_seocode (id, code, description) VALUES (385,'950408','Technological Ethics');
INSERT INTO crams_seocode (id, code, description) VALUES (386,'950409','Workplace and Organisational Ethics');
INSERT INTO crams_seocode (id, code, description) VALUES (387,'950499','Religion and Ethics not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (388,'950504','Understanding Europe''s Past');
INSERT INTO crams_seocode (id, code, description) VALUES (389,'959999','Cultural Understanding not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (390,'960104','Marine Air Quality');
INSERT INTO crams_seocode (id, code, description) VALUES (391,'960201','Atmospheric Composition (incl. Greenhouse Gas Inventory)');
INSERT INTO crams_seocode (id, code, description) VALUES (392,'960301','Climate Change Adaptation Measures');
INSERT INTO crams_seocode (id, code, description) VALUES (393,'960305','Ecosystem Adaptation to Climate Change');
INSERT INTO crams_seocode (id, code, description) VALUES (394,'960309','Effects of Climate Change and Variability on the South Pacific (excl. Australia and New Zealand) (excl. Social Impacts)');
INSERT INTO crams_seocode (id, code, description) VALUES (395,'960310','Global Effects of Climate Change and Variability (excl. Australia, New Zealand, Antarctica and the South Pacific) (excl. Social Impacts)');
INSERT INTO crams_seocode (id, code, description) VALUES (396,'960311','Social Impacts of Climate Change and Variability');
INSERT INTO crams_seocode (id, code, description) VALUES (397,'960399','Climate and Climate Change not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (398,'960402','Control of Animal Pests, Diseases and Exotic Species in Coastal and Estuarine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (399,'960403','Control of Animal Pests, Diseases and Exotic Species in Farmland, Arable Cropland and Permanent Cropland Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (400,'960404','Control of Animal Pests, Diseases and Exotic Species in Forest and Woodlands Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (401,'960405','Control of Pests, Diseases and Exotic Species at Regional or Larger Scales');
INSERT INTO crams_seocode (id, code, description) VALUES (402,'960406','Control of Pests, Diseases and Exotic Species in Fresh, Ground and Surface Water Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (403,'960407','Control of Pests, Diseases and Exotic Species in Marine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (404,'960408','Control of Pests, Diseases and Exotic Species in Mining Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (405,'960409','Control of Pests, Diseases and Exotic Species in Mountain and High Country Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (406,'960410','Control of Pests, Diseases and Exotic Species in Sparseland, Permanent Grassland and Arid Zone Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (407,'960411','Control of Pests, Diseases and Exotic Species in Urban and Industrial Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (408,'960412','Control of Plant Pests, Diseases and Exotic Species in Coastal and Estuarine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (409,'960413','Control of Plant Pests, Diseases and Exotic Species in Farmland, Arable Cropland and Permanent Cropland Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (410,'960414','Control of Plant Pests, Diseases and Exotic Species in Forest and Woodlands Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (411,'960415','Pre-Border Biosecurity');
INSERT INTO crams_seocode (id, code, description) VALUES (412,'960499','Control of Pests, Diseases and Exotic Species not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (413,'960501','Ecosystem Assessment and Management at Regional or Larger Scales');
INSERT INTO crams_seocode (id, code, description) VALUES (414,'960502','Ecosystem Assessment and Management of Antarctic and Sub-Antarctic Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (415,'960503','Ecosystem Assessment and Management of Coastal and Estuarine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (416,'960504','Ecosystem Assessment and Management of Farmland, Arable Cropland and Permanent Cropland Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (417,'960505','Ecosystem Assessment and Management of Forest and Woodlands Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (418,'960506','Ecosystem Assessment and Management of Fresh, Ground and Surface Water Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (419,'960507','Ecosystem Assessment and Management of Marine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (420,'960508','Ecosystem Assessment and Management of Mining Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (421,'960509','Ecosystem Assessment and Management of Mountain and High Country Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (422,'960510','Ecosystem Assessment and Management of Sparseland, Permanent Grassland and Arid Zone Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (423,'960511','Ecosystem Assessment and Management of Urban and Industrial Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (424,'960599','Ecosystem Assessment and Management not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (425,'960601','Economic Incentives for Environmental Protection');
INSERT INTO crams_seocode (id, code, description) VALUES (426,'960602','Eco-Verification (excl. Environmental Lifecycle Assessment)');
INSERT INTO crams_seocode (id, code, description) VALUES (427,'960603','Environmental Lifecycle Assessment');
INSERT INTO crams_seocode (id, code, description) VALUES (428,'960606','Rights to Environmental and Natural Resources (excl. Water Allocation)');
INSERT INTO crams_seocode (id, code, description) VALUES (429,'960607','Rural Land Evaluation');
INSERT INTO crams_seocode (id, code, description) VALUES (430,'960608','Rural Water Evaluation (incl. Water Quality)');
INSERT INTO crams_seocode (id, code, description) VALUES (431,'960609','Sustainability Indicators');
INSERT INTO crams_seocode (id, code, description) VALUES (432,'960610','Urban Land Evaluation');
INSERT INTO crams_seocode (id, code, description) VALUES (433,'960699','Environmental and Natural Resource Evaluation not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (434,'960701','Coastal and Marine Management Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (435,'960703','Environmental Education and Awareness');
INSERT INTO crams_seocode (id, code, description) VALUES (436,'960705','Rural Land Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (437,'960706','Rural Water Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (438,'960707','Trade and Environment');
INSERT INTO crams_seocode (id, code, description) VALUES (439,'960708','Urban Land Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (440,'960709','Urban Water Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (441,'960799','Environmental Policy, Legislation and Standards not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (442,'960801','Antarctic and Sub-Antarctic Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (443,'960802','Coastal and Estuarine Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (444,'960803','Documentation of Undescribed Flora and Fauna');
INSERT INTO crams_seocode (id, code, description) VALUES (445,'960804','Farmland, Arable Cropland and Permanent Cropland Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (446,'960805','Flora, Fauna and Biodiversity at Regional or Larger Scales');
INSERT INTO crams_seocode (id, code, description) VALUES (447,'960811','Sparseland, Permanent Grassland and Arid Zone Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (448,'960904','Farmland, Arable Cropland and Permanent Cropland Land Management');
INSERT INTO crams_seocode (id, code, description) VALUES (449,'960910','Sparseland, Permanent Grassland and Arid Zone Land and Water Management');
INSERT INTO crams_seocode (id, code, description) VALUES (450,'961002','Natural Hazards in Coastal and Estuarine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (451,'961008','Natural Hazards in Mountain and High Country Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (452,'961103','Physical and Chemical Conditions of Water in Fresh, Ground and Surface Water Environments (excl. Urban and Industrial Use)');
INSERT INTO crams_seocode (id, code, description) VALUES (453,'961104','Physical and Chemical Conditions of Water in Marine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (454,'961199','Physical and Chemical Conditions of Water not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (455,'961201','Rehabilitation of Degraded Coastal and Estuarine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (456,'961202','Rehabilitation of Degraded Farmland, Arable Cropland and Permanent Cropland Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (457,'961203','Rehabilitation of Degraded Forest and Woodlands Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (458,'961204','Rehabilitation of Degraded Fresh, Ground and Surface Water Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (459,'961205','Rehabilitation of Degraded Mining Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (460,'961206','Rehabilitation of Degraded Mountain and High Country Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (461,'961207','Rehabilitation of Degraded Sparseland, Permanent Grassland and Arid Zone Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (462,'961208','Rehabilitation of Degraded Urban and Industrial Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (463,'961299','Rehabilitation of Degraded Environments not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (464,'961301','Protected Conservation Areas in Antarctic and Sub-Antarctic Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (465,'961302','Protected Conservation Areas in Fresh, Ground and Surface Water Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (466,'961303','Protected Conservation Areas in Marine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (467,'961304','Remnant Vegetation and Protected Conservation Areas in Coastal and Estuarine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (468,'961305','Remnant Vegetation and Protected Conservation Areas in Farmland, Arable Cropland and Permanent Cropland Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (469,'961306','Remnant Vegetation and Protected Conservation Areas in Forest and Woodlands Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (470,'961307','Remnant Vegetation and Protected Conservation Areas in Mountain and High Country Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (471,'961308','Remnant Vegetation and Protected Conservation Areas at Regional or Larger Scales');
INSERT INTO crams_seocode (id, code, description) VALUES (472,'961309','Remnant Vegetation and Protected Conservation Areas in Sparseland, Permanent Grassland and Arid Zone Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (473,'961310','Remnant Vegetation and Protected Conservation Areas in Urban and Industrial Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (474,'961399','Remnant Vegetation and Protected Conservation Areas not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (475,'961401','Coastal and Estuarine Soils');
INSERT INTO crams_seocode (id, code, description) VALUES (476,'961402','Farmland, Arable Cropland and Permanent Cropland Soils');
INSERT INTO crams_seocode (id, code, description) VALUES (477,'961403','Forest and Woodlands Soils');
INSERT INTO crams_seocode (id, code, description) VALUES (478,'961404','Mining Soils');
INSERT INTO crams_seocode (id, code, description) VALUES (479,'961405','Mountain and High Country Soils');
INSERT INTO crams_seocode (id, code, description) VALUES (480,'961406','Sparseland, Permanent Grassland and Arid Zone Soils');
INSERT INTO crams_seocode (id, code, description) VALUES (481,'961407','Urban and Industrial Soils');
INSERT INTO crams_seocode (id, code, description) VALUES (482,'961499','Soils not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (483,'969901','Antarctic and Sub-Antarctic Oceanography');
INSERT INTO crams_seocode (id, code, description) VALUES (484,'969902','Marine Oceanic Processes (excl. climate related)');
INSERT INTO crams_seocode (id, code, description) VALUES (485,'969999','Environment not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (486,'970101','Expanding Knowledge in the Mathematical Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (487,'970102','Expanding Knowledge in the Physical Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (488,'970103','Expanding Knowledge in the Chemical Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (489,'970104','Expanding Knowledge in the Earth Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (490,'970105','Expanding Knowledge in the Environmental Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (491,'970106','Expanding Knowledge in the Biological Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (492,'970107','Expanding Knowledge in the Agricultural and Veterinary Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (493,'970108','Expanding Knowledge in the Information and Computing Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (494,'970109','Expanding Knowledge in Engineering');
INSERT INTO crams_seocode (id, code, description) VALUES (495,'970110','Expanding Knowledge in Technology');
INSERT INTO crams_seocode (id, code, description) VALUES (496,'970111','Expanding Knowledge in the Medical and Health Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (497,'970112','Expanding Knowledge in Built Environment and Design');
INSERT INTO crams_seocode (id, code, description) VALUES (498,'970113','Expanding Knowledge in Education');
INSERT INTO crams_seocode (id, code, description) VALUES (499,'970114','Expanding Knowledge in Economics');
INSERT INTO crams_seocode (id, code, description) VALUES (500,'970115','Expanding Knowledge in Commerce, Management, Tourism and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (501,'970116','Expanding Knowledge through Studies of Human Society');
INSERT INTO crams_seocode (id, code, description) VALUES (502,'970117','Expanding Knowledge in Psychology and Cognitive Sciences');
INSERT INTO crams_seocode (id, code, description) VALUES (503,'970118','Expanding Knowledge in Law and Legal Studies');
INSERT INTO crams_seocode (id, code, description) VALUES (504,'970119','Expanding Knowledge through Studies of the Creative Arts and Writing');
INSERT INTO crams_seocode (id, code, description) VALUES (505,'970120','Expanding Knowledge in Language, Communication and Culture');
INSERT INTO crams_seocode (id, code, description) VALUES (506,'970121','Expanding Knowledge in History and Archaeology');
INSERT INTO crams_seocode (id, code, description) VALUES (507,'970122','Expanding Knowledge in Philosophy and Religious Studies');
INSERT INTO crams_seocode (id, code, description) VALUES (508,'81','Defence');
INSERT INTO crams_seocode (id, code, description) VALUES (509,'8101','Defence');
INSERT INTO crams_seocode (id, code, description) VALUES (510,'82','Plant Production and Plant Primary Products');
INSERT INTO crams_seocode (id, code, description) VALUES (511,'8201','Forestry');
INSERT INTO crams_seocode (id, code, description) VALUES (512,'8202','Horticultural Crops');
INSERT INTO crams_seocode (id, code, description) VALUES (513,'8203','Industrial Crops');
INSERT INTO crams_seocode (id, code, description) VALUES (514,'8204','Summer Grains and Oilseeds');
INSERT INTO crams_seocode (id, code, description) VALUES (515,'8205','Winter Grains and Oilseeds');
INSERT INTO crams_seocode (id, code, description) VALUES (516,'8206','Harvesting and Packing of Plant Products');
INSERT INTO crams_seocode (id, code, description) VALUES (517,'8298','Environmentally Sustainable Plant Production');
INSERT INTO crams_seocode (id, code, description) VALUES (518,'8299','Other Plant Production and Plant Primary Products');
INSERT INTO crams_seocode (id, code, description) VALUES (519,'83','Animal Production and Animal Primary Products');
INSERT INTO crams_seocode (id, code, description) VALUES (520,'8301','Fisheries - Aquaculture');
INSERT INTO crams_seocode (id, code, description) VALUES (521,'8302','Fisheries - Wild Caught');
INSERT INTO crams_seocode (id, code, description) VALUES (522,'8303','Livestock Raising');
INSERT INTO crams_seocode (id, code, description) VALUES (523,'8304','Pasture, Browse and Fodder Crops');
INSERT INTO crams_seocode (id, code, description) VALUES (524,'8305','Primary Animal Products');
INSERT INTO crams_seocode (id, code, description) VALUES (525,'8398','Environmentally Sustainable Animal Production');
INSERT INTO crams_seocode (id, code, description) VALUES (526,'8399','Other Animal Production and Animal Primary Products');
INSERT INTO crams_seocode (id, code, description) VALUES (527,'84','Mineral Resources (excl. Energy Resources)');
INSERT INTO crams_seocode (id, code, description) VALUES (528,'8401','Mineral Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (529,'8402','Primary Mining and Extraction of Mineral Resources');
INSERT INTO crams_seocode (id, code, description) VALUES (530,'8403','First Stage Treatment of Ores and Minerals');
INSERT INTO crams_seocode (id, code, description) VALUES (531,'8498','Environmentally Sustainable Mineral Resource Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (532,'8499','Other Mineral Resources (excl. Energy Resources)');
INSERT INTO crams_seocode (id, code, description) VALUES (533,'85','Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (534,'8501','Energy Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (535,'8502','Mining and Extraction of Energy Resources');
INSERT INTO crams_seocode (id, code, description) VALUES (536,'8503','Preparation and Production of Energy Sources');
INSERT INTO crams_seocode (id, code, description) VALUES (537,'8504','Energy Transformation');
INSERT INTO crams_seocode (id, code, description) VALUES (538,'8505','Renewable Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (539,'8506','Energy Storage, Distribution and Supply');
INSERT INTO crams_seocode (id, code, description) VALUES (540,'8507','Energy Conservation and Efficiency');
INSERT INTO crams_seocode (id, code, description) VALUES (541,'8598','Environmentally Sustainable Energy Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (542,'8599','Other Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (543,'86','Manufacturing');
INSERT INTO crams_seocode (id, code, description) VALUES (544,'8601','Processed Food Products and Beverages (excl. Dairy Products)');
INSERT INTO crams_seocode (id, code, description) VALUES (545,'8602','Dairy Products');
INSERT INTO crams_seocode (id, code, description) VALUES (546,'8603','Processed Non-Food Agriculture Products (excl. Wood, Paper and Fibre)');
INSERT INTO crams_seocode (id, code, description) VALUES (547,'8604','Leather Products, Fibre Processing and Textiles');
INSERT INTO crams_seocode (id, code, description) VALUES (548,'8605','Wood, Wood Products and Paper');
INSERT INTO crams_seocode (id, code, description) VALUES (549,'8606','Industrial Chemicals and Related Products');
INSERT INTO crams_seocode (id, code, description) VALUES (550,'8607','Agricultural Chemicals');
INSERT INTO crams_seocode (id, code, description) VALUES (551,'8608','Human Pharmaceutical Products');
INSERT INTO crams_seocode (id, code, description) VALUES (552,'8609','Veterinary Pharmaceutical Products');
INSERT INTO crams_seocode (id, code, description) VALUES (553,'8610','Ceramics, Glass and Industrial Mineral Products');
INSERT INTO crams_seocode (id, code, description) VALUES (554,'8611','Basic Metal Products (incl. Smelting, Rolling, Drawing and Extruding)');
INSERT INTO crams_seocode (id, code, description) VALUES (555,'8612','Fabricated Metal Products');
INSERT INTO crams_seocode (id, code, description) VALUES (556,'8613','Transport Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (557,'8614','Machinery and Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (558,'8615','Instrumentation');
INSERT INTO crams_seocode (id, code, description) VALUES (559,'8616','Computer Hardware and Electronic Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (560,'8617','Communication Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (561,'8698','Environmentally Sustainable Manufacturing');
INSERT INTO crams_seocode (id, code, description) VALUES (562,'8699','Other Manufacturing');
INSERT INTO crams_seocode (id, code, description) VALUES (563,'87','Construction');
INSERT INTO crams_seocode (id, code, description) VALUES (564,'8701','Construction Planning');
INSERT INTO crams_seocode (id, code, description) VALUES (565,'8702','Construction Design');
INSERT INTO crams_seocode (id, code, description) VALUES (566,'8703','Construction Materials Performance and Processes');
INSERT INTO crams_seocode (id, code, description) VALUES (567,'8704','Construction Processes');
INSERT INTO crams_seocode (id, code, description) VALUES (568,'8705','Building Management and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (569,'8798','Environmentally Sustainable Construction');
INSERT INTO crams_seocode (id, code, description) VALUES (570,'8799','Other Construction');
INSERT INTO crams_seocode (id, code, description) VALUES (571,'88','Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (572,'8801','Ground Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (573,'8802','Water Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (574,'8803','Aerospace Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (575,'8898','Environmentally Sustainable Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (576,'8899','Other Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (577,'89','Information and Communication Services');
INSERT INTO crams_seocode (id, code, description) VALUES (578,'8901','Communication Networks and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (579,'8902','Computer Software and Services');
INSERT INTO crams_seocode (id, code, description) VALUES (580,'8903','Information Services');
INSERT INTO crams_seocode (id, code, description) VALUES (581,'8904','Media Services');
INSERT INTO crams_seocode (id, code, description) VALUES (582,'8998','Environmentally Sustainable Information and Communication Services');
INSERT INTO crams_seocode (id, code, description) VALUES (583,'8999','Other Information and Communication Services');
INSERT INTO crams_seocode (id, code, description) VALUES (584,'90','Commercial Services and Tourism');
INSERT INTO crams_seocode (id, code, description) VALUES (585,'9001','Financial Services');
INSERT INTO crams_seocode (id, code, description) VALUES (586,'9002','Property, Business Support Services and Trade');
INSERT INTO crams_seocode (id, code, description) VALUES (587,'9003','Tourism');
INSERT INTO crams_seocode (id, code, description) VALUES (588,'9004','Water and Waste Services');
INSERT INTO crams_seocode (id, code, description) VALUES (589,'9098','Environmentally Sustainable Commercial Services and Tourism');
INSERT INTO crams_seocode (id, code, description) VALUES (590,'9099','Other Commercial Services and Tourism');
INSERT INTO crams_seocode (id, code, description) VALUES (591,'91','Economic Framework');
INSERT INTO crams_seocode (id, code, description) VALUES (592,'9101','Macroeconomics');
INSERT INTO crams_seocode (id, code, description) VALUES (593,'9102','Microeconomics');
INSERT INTO crams_seocode (id, code, description) VALUES (594,'9103','International Trade');
INSERT INTO crams_seocode (id, code, description) VALUES (595,'9104','Management and Productivity');
INSERT INTO crams_seocode (id, code, description) VALUES (596,'9105','Measurement Standards and Calibration Services');
INSERT INTO crams_seocode (id, code, description) VALUES (597,'9199','Other Economic Framework');
INSERT INTO crams_seocode (id, code, description) VALUES (598,'92','Health');
INSERT INTO crams_seocode (id, code, description) VALUES (599,'9201','Clinical Health (Organs, Diseases and Abnormal Conditions)');
INSERT INTO crams_seocode (id, code, description) VALUES (600,'9202','Health and Support Services');
INSERT INTO crams_seocode (id, code, description) VALUES (601,'9203','Indigenous Health');
INSERT INTO crams_seocode (id, code, description) VALUES (602,'9204','Public Health (excl. Specific Population Health)');
INSERT INTO crams_seocode (id, code, description) VALUES (603,'9205','Specific Population Health (excl. Indigenous Health)');
INSERT INTO crams_seocode (id, code, description) VALUES (604,'9299','Other Health');
INSERT INTO crams_seocode (id, code, description) VALUES (605,'93','Education and Training');
INSERT INTO crams_seocode (id, code, description) VALUES (606,'9301','Learner and Learning');
INSERT INTO crams_seocode (id, code, description) VALUES (607,'9302','Teaching and Instruction');
INSERT INTO crams_seocode (id, code, description) VALUES (608,'9303','Curriculum');
INSERT INTO crams_seocode (id, code, description) VALUES (609,'9304','School/Institution');
INSERT INTO crams_seocode (id, code, description) VALUES (610,'9305','Education and Training Systems');
INSERT INTO crams_seocode (id, code, description) VALUES (611,'9399','Other Education and Training');
INSERT INTO crams_seocode (id, code, description) VALUES (612,'94','Law, Politics and Community Services');
INSERT INTO crams_seocode (id, code, description) VALUES (613,'9401','Community Service (excl. Work)');
INSERT INTO crams_seocode (id, code, description) VALUES (614,'9402','Government and Politics');
INSERT INTO crams_seocode (id, code, description) VALUES (615,'9403','International Relations');
INSERT INTO crams_seocode (id, code, description) VALUES (616,'9404','Justice and the Law');
INSERT INTO crams_seocode (id, code, description) VALUES (617,'9405','Work and Institutional Development');
INSERT INTO crams_seocode (id, code, description) VALUES (618,'9499','Other Law, Politics and Community Services');
INSERT INTO crams_seocode (id, code, description) VALUES (619,'95','Cultural Understanding');
INSERT INTO crams_seocode (id, code, description) VALUES (620,'9501','Arts and Leisure');
INSERT INTO crams_seocode (id, code, description) VALUES (621,'9502','Communication');
INSERT INTO crams_seocode (id, code, description) VALUES (622,'9503','Heritage');
INSERT INTO crams_seocode (id, code, description) VALUES (623,'9504','Religion and Ethics');
INSERT INTO crams_seocode (id, code, description) VALUES (624,'9505','Understanding Past Societies');
INSERT INTO crams_seocode (id, code, description) VALUES (625,'9599','Other Cultural Understanding');
INSERT INTO crams_seocode (id, code, description) VALUES (626,'96','Environment');
INSERT INTO crams_seocode (id, code, description) VALUES (627,'9601','Air Quality');
INSERT INTO crams_seocode (id, code, description) VALUES (628,'9602','Atmosphere and Weather');
INSERT INTO crams_seocode (id, code, description) VALUES (629,'9603','Climate and Climate Change');
INSERT INTO crams_seocode (id, code, description) VALUES (630,'9604','Control of Pests, Diseases and Exotic Species');
INSERT INTO crams_seocode (id, code, description) VALUES (631,'9605','Ecosystem Assessment and Management');
INSERT INTO crams_seocode (id, code, description) VALUES (632,'9606','Environmental and Natural Resource Evaluation');
INSERT INTO crams_seocode (id, code, description) VALUES (633,'9607','Environmental Policy, Legislation and Standards');
INSERT INTO crams_seocode (id, code, description) VALUES (634,'9608','Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (635,'9609','Land and Water Management');
INSERT INTO crams_seocode (id, code, description) VALUES (636,'9610','Natural Hazards');
INSERT INTO crams_seocode (id, code, description) VALUES (637,'9611','Physical and Chemical Conditions of Water');
INSERT INTO crams_seocode (id, code, description) VALUES (638,'9612','Rehabilitation of Degraded Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (639,'9613','Remnant Vegetation and Protected Conservation Areas');
INSERT INTO crams_seocode (id, code, description) VALUES (640,'9614','Soils');
INSERT INTO crams_seocode (id, code, description) VALUES (641,'9699','Other Environment');
INSERT INTO crams_seocode (id, code, description) VALUES (642,'97','Expanding Knowledge');
INSERT INTO crams_seocode (id, code, description) VALUES (643,'9701','Expanding Knowledge');
INSERT INTO crams_seocode (id, code, description) VALUES (644,'810104','Emerging Defence Technologies');
INSERT INTO crams_seocode (id, code, description) VALUES (645,'810105','Intelligence');
INSERT INTO crams_seocode (id, code, description) VALUES (646,'810106','Logistics');
INSERT INTO crams_seocode (id, code, description) VALUES (647,'810107','National Security');
INSERT INTO crams_seocode (id, code, description) VALUES (648,'810109','Personnel');
INSERT INTO crams_seocode (id, code, description) VALUES (649,'820101','Hardwood Plantations');
INSERT INTO crams_seocode (id, code, description) VALUES (650,'820102','Harvesting and Transport of Forest Products');
INSERT INTO crams_seocode (id, code, description) VALUES (651,'820103','Integration of Farm and Forestry');
INSERT INTO crams_seocode (id, code, description) VALUES (652,'820104','Native Forests');
INSERT INTO crams_seocode (id, code, description) VALUES (653,'820199','Forestry not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (654,'820201','Almonds');
INSERT INTO crams_seocode (id, code, description) VALUES (655,'820202','Berry Fruit (excl. Kiwifruit)');
INSERT INTO crams_seocode (id, code, description) VALUES (656,'820203','Citrus Fruit');
INSERT INTO crams_seocode (id, code, description) VALUES (657,'820205','Kiwifruit');
INSERT INTO crams_seocode (id, code, description) VALUES (658,'820208','Olives');
INSERT INTO crams_seocode (id, code, description) VALUES (659,'820209','Ornamentals, Natives, Flowers and Nursery Plants');
INSERT INTO crams_seocode (id, code, description) VALUES (660,'820210','Pome Fruit, Pip Fruit');
INSERT INTO crams_seocode (id, code, description) VALUES (661,'820211','Stone Fruit');
INSERT INTO crams_seocode (id, code, description) VALUES (662,'820405','Soybeans');
INSERT INTO crams_seocode (id, code, description) VALUES (663,'830204','Wild Caught Fin Fish (excl. Tuna)');
INSERT INTO crams_seocode (id, code, description) VALUES (664,'830205','Wild Caught Prawns');
INSERT INTO crams_seocode (id, code, description) VALUES (665,'830206','Wild Caught Rock Lobster');
INSERT INTO crams_seocode (id, code, description) VALUES (666,'830299','Fisheries - Wild Caught not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (667,'830301','Beef Cattle');
INSERT INTO crams_seocode (id, code, description) VALUES (668,'830302','Dairy Cattle');
INSERT INTO crams_seocode (id, code, description) VALUES (669,'830304','Goats');
INSERT INTO crams_seocode (id, code, description) VALUES (670,'830305','Game Livestock (e.g. Kangaroos, Wallabies, Camels, Buffaloes, Possums)');
INSERT INTO crams_seocode (id, code, description) VALUES (671,'830306','Horses');
INSERT INTO crams_seocode (id, code, description) VALUES (672,'830308','Pigs');
INSERT INTO crams_seocode (id, code, description) VALUES (673,'830309','Poultry');
INSERT INTO crams_seocode (id, code, description) VALUES (674,'830310','Sheep - Meat');
INSERT INTO crams_seocode (id, code, description) VALUES (675,'830399','Livestock Raising not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (676,'830401','Browse Crops');
INSERT INTO crams_seocode (id, code, description) VALUES (677,'830402','Lucerne');
INSERT INTO crams_seocode (id, code, description) VALUES (678,'830404','Non-Cereal Crops for Hay');
INSERT INTO crams_seocode (id, code, description) VALUES (679,'830405','Non-Cereal Crops for Silage/Green Feed');
INSERT INTO crams_seocode (id, code, description) VALUES (680,'830406','Sown Pastures (excl. Lucerne)');
INSERT INTO crams_seocode (id, code, description) VALUES (681,'830501','Eggs');
INSERT INTO crams_seocode (id, code, description) VALUES (682,'830503','Live Animals');
INSERT INTO crams_seocode (id, code, description) VALUES (683,'830504','Pearls');
INSERT INTO crams_seocode (id, code, description) VALUES (684,'830506','Unprocessed or Minimally Processed Fish');
INSERT INTO crams_seocode (id, code, description) VALUES (685,'830507','Unprocessed or Minimally Processed Milk');
INSERT INTO crams_seocode (id, code, description) VALUES (686,'830599','Primary Animal Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (687,'840107','Titanium Minerals, Zircon, and Rare Earth Metal Ore (e.g. Monazite) Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (688,'840204','Mining and Extraction of Iron Ores');
INSERT INTO crams_seocode (id, code, description) VALUES (689,'849803','Management of Liquid Waste from Mineral Resource Activities (excl. Water)');
INSERT INTO crams_seocode (id, code, description) VALUES (690,'849804','Management of Solid Waste from Mineral Resource Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (691,'850104','Oil Shale and Tar Sands Exploration');
INSERT INTO crams_seocode (id, code, description) VALUES (692,'850199','Energy Exploration not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (693,'850202','Geothermal Energy Extraction');
INSERT INTO crams_seocode (id, code, description) VALUES (694,'850204','Oil Shale and Tar Sands Mining and Extraction');
INSERT INTO crams_seocode (id, code, description) VALUES (695,'850205','Uranium Mining and Extraction');
INSERT INTO crams_seocode (id, code, description) VALUES (696,'850299','Mining and Extraction of Energy Resources not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (697,'850302','Hydrogen Production from Nuclear Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (698,'850303','Hydrogen Production from Renewable Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (699,'850304','Oil and Gas Refining');
INSERT INTO crams_seocode (id, code, description) VALUES (700,'850306','Preparation of Brown Coal (Lignite)');
INSERT INTO crams_seocode (id, code, description) VALUES (701,'850307','Preparation of Oil Shale and Tar Sands');
INSERT INTO crams_seocode (id, code, description) VALUES (702,'850308','Preparation of Uranium');
INSERT INTO crams_seocode (id, code, description) VALUES (703,'850399','Preparation and Production of Energy Sources not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (704,'850401','Fuel Cells (excl. Solid Oxide)');
INSERT INTO crams_seocode (id, code, description) VALUES (705,'850402','Hydrogen-based Energy Systems (incl. Internal Hydrogen Combustion Engines)');
INSERT INTO crams_seocode (id, code, description) VALUES (706,'850404','Solid Oxide Fuel Cells');
INSERT INTO crams_seocode (id, code, description) VALUES (707,'850405','Transformation of Black Coal into Electricity');
INSERT INTO crams_seocode (id, code, description) VALUES (708,'850406','Transformation of Brown Coal (Lignite) into Electricity');
INSERT INTO crams_seocode (id, code, description) VALUES (709,'850408','Transformation of Coal into Liquid Fuels');
INSERT INTO crams_seocode (id, code, description) VALUES (710,'850409','Transformation of Gas into Electricity');
INSERT INTO crams_seocode (id, code, description) VALUES (711,'850410','Transformation of Gas into Liquid Fuels');
INSERT INTO crams_seocode (id, code, description) VALUES (712,'850501','Biofuel (Biomass) Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (713,'850502','Geothermal Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (714,'850504','Solar-Photovoltaic Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (715,'850506','Solar-Thermal Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (716,'850508','Wave Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (717,'850509','Wind Energy');
INSERT INTO crams_seocode (id, code, description) VALUES (718,'850599','Renewable Energy not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (719,'850703','Industrial Energy Conservation and Efficiency');
INSERT INTO crams_seocode (id, code, description) VALUES (720,'859999','Energy not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (721,'860109','Processed Meat Products');
INSERT INTO crams_seocode (id, code, description) VALUES (722,'860110','Soy Products');
INSERT INTO crams_seocode (id, code, description) VALUES (723,'860199','Processed Food Products and Beverages (excl. Dairy Products) not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (724,'860201','Butter and Milk-Derived Fats and Oils (excl. Cream)');
INSERT INTO crams_seocode (id, code, description) VALUES (725,'860203','Cheese');
INSERT INTO crams_seocode (id, code, description) VALUES (726,'860204','Processed Milk and Cream (incl. Powder, Evaporated and Condensed)');
INSERT INTO crams_seocode (id, code, description) VALUES (727,'860299','Dairy Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (728,'860301','Essential Oils (e.g. Tea Tree, Eucalyptus, Lavender, Peppermint, Boronia, Sandalwood)');
INSERT INTO crams_seocode (id, code, description) VALUES (729,'860303','Plant Extracts (e.g. Pyrethrum, Alkaloids, Jojoba Oil)');
INSERT INTO crams_seocode (id, code, description) VALUES (730,'860304','Prepared Animal Feed');
INSERT INTO crams_seocode (id, code, description) VALUES (731,'860401','Clothing');
INSERT INTO crams_seocode (id, code, description) VALUES (732,'860402','Cotton Ginning');
INSERT INTO crams_seocode (id, code, description) VALUES (733,'860404','Non-Fabric Textiles (e.g. Felt)');
INSERT INTO crams_seocode (id, code, description) VALUES (734,'860405','Processed Skins, Leather and Leather Products');
INSERT INTO crams_seocode (id, code, description) VALUES (735,'860406','Synthetic Fibres, Yarns and Fabrics');
INSERT INTO crams_seocode (id, code, description) VALUES (736,'860407','Wool Scouring and Top Making');
INSERT INTO crams_seocode (id, code, description) VALUES (737,'860699','Industrial Chemicals and Related Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (738,'861099','Ceramics, Glass and Industrial Mineral Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (739,'861101','Basic Aluminium Products');
INSERT INTO crams_seocode (id, code, description) VALUES (740,'861299','Fabricated Metal Products not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (741,'861304','Rail Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (742,'861503','Scientific Instruments');
INSERT INTO crams_seocode (id, code, description) VALUES (743,'861599','Instrumentation not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (744,'861601','Computer and Electronic Office Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (745,'861602','Consumer Electronic Equipment (excl. Communication Equipment)');
INSERT INTO crams_seocode (id, code, description) VALUES (746,'861603','Integrated Circuits and Devices');
INSERT INTO crams_seocode (id, code, description) VALUES (747,'861604','Integrated Systems');
INSERT INTO crams_seocode (id, code, description) VALUES (748,'861606','Satellite Navigation Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (749,'861701','Network Infrastructure Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (750,'861702','Telemetry Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (751,'861703','Voice and Data Equipment');
INSERT INTO crams_seocode (id, code, description) VALUES (752,'861799','Communication Equipment not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (753,'869802','Management of Greenhouse Gas Emissions from Manufacturing Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (754,'869803','Management of Liquid Waste from Manufacturing Activities (excl. Water)');
INSERT INTO crams_seocode (id, code, description) VALUES (755,'869804','Management of Solid Waste from Manufacturing Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (756,'869805','Management of Water Consumption by Manufacturing Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (757,'869899','Environmentally Sustainable Manufacturing not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (758,'869901','Furniture');
INSERT INTO crams_seocode (id, code, description) VALUES (759,'870101','Civil Construction Planning');
INSERT INTO crams_seocode (id, code, description) VALUES (760,'870102','Commercial Construction Planning');
INSERT INTO crams_seocode (id, code, description) VALUES (761,'870103','Regional Planning');
INSERT INTO crams_seocode (id, code, description) VALUES (762,'870104','Residential Construction Planning');
INSERT INTO crams_seocode (id, code, description) VALUES (763,'870105','Urban Planning');
INSERT INTO crams_seocode (id, code, description) VALUES (764,'870199','Construction Planning not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (765,'870202','Commercial Construction Design');
INSERT INTO crams_seocode (id, code, description) VALUES (766,'870203','Industrial Construction Design');
INSERT INTO crams_seocode (id, code, description) VALUES (767,'870204','Residential Construction Design');
INSERT INTO crams_seocode (id, code, description) VALUES (768,'870299','Construction Design not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (769,'870301','Cement and Concrete Materials');
INSERT INTO crams_seocode (id, code, description) VALUES (770,'870302','Metals (e.g. Composites, Coatings, Bonding)');
INSERT INTO crams_seocode (id, code, description) VALUES (771,'870304','Stone, Ceramics and Clay Materials');
INSERT INTO crams_seocode (id, code, description) VALUES (772,'870305','Timber Materials');
INSERT INTO crams_seocode (id, code, description) VALUES (773,'870399','Construction Materials Performance and Processes not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (774,'870401','Civil Construction Processes');
INSERT INTO crams_seocode (id, code, description) VALUES (775,'870402','Commercial Construction Processes');
INSERT INTO crams_seocode (id, code, description) VALUES (776,'870403','Industrial Construction Processes');
INSERT INTO crams_seocode (id, code, description) VALUES (777,'870499','Construction Processes not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (778,'880203','International Sea Transport of Live Animals');
INSERT INTO crams_seocode (id, code, description) VALUES (779,'880305','Space Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (780,'880399','Aerospace Transport not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (781,'889802','Management of Greenhouse Gas Emissions from Transport Activities');
INSERT INTO crams_seocode (id, code, description) VALUES (782,'889899','Environmentally Sustainable Transport not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (783,'889902','Multimodal Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (784,'889903','Pipeline Transport');
INSERT INTO crams_seocode (id, code, description) VALUES (785,'890201','Application Software Packages (excl. Computer Games)');
INSERT INTO crams_seocode (id, code, description) VALUES (786,'890203','Computer Gaming Software');
INSERT INTO crams_seocode (id, code, description) VALUES (787,'909899','Environmentally Sustainable Commercial Services and Tourism not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (788,'910102','Demography');
INSERT INTO crams_seocode (id, code, description) VALUES (789,'910104','Exchange Rates');
INSERT INTO crams_seocode (id, code, description) VALUES (790,'910109','Savings and Investments');
INSERT INTO crams_seocode (id, code, description) VALUES (791,'910202','Human Capital Issues');
INSERT INTO crams_seocode (id, code, description) VALUES (792,'910205','Industry Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (793,'910207','Microeconomic Effects of Taxation');
INSERT INTO crams_seocode (id, code, description) VALUES (794,'910208','Micro Labour Market Issues');
INSERT INTO crams_seocode (id, code, description) VALUES (795,'910210','Production');
INSERT INTO crams_seocode (id, code, description) VALUES (796,'910211','Supply and Demand');
INSERT INTO crams_seocode (id, code, description) VALUES (797,'910299','Microeconomics not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (798,'910301','International Agreements on Trade');
INSERT INTO crams_seocode (id, code, description) VALUES (799,'910302','Trade Assistance and Protection');
INSERT INTO crams_seocode (id, code, description) VALUES (800,'910303','Trade Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (801,'910399','International Trade not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (802,'910401','Industrial Relations');
INSERT INTO crams_seocode (id, code, description) VALUES (803,'910402','Management');
INSERT INTO crams_seocode (id, code, description) VALUES (804,'910403','Marketing');
INSERT INTO crams_seocode (id, code, description) VALUES (805,'910404','Productivity (excl. Public Sector)');
INSERT INTO crams_seocode (id, code, description) VALUES (806,'910405','Public Sector Productivity');
INSERT INTO crams_seocode (id, code, description) VALUES (807,'910406','Technological and Organisational Innovation');
INSERT INTO crams_seocode (id, code, description) VALUES (808,'910499','Management and Productivity not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (809,'910501','Agricultural and Environmental Standards');
INSERT INTO crams_seocode (id, code, description) VALUES (810,'910503','Manufacturing Standards and Calibrations');
INSERT INTO crams_seocode (id, code, description) VALUES (811,'910504','Service Industries Standards and Calibrations');
INSERT INTO crams_seocode (id, code, description) VALUES (812,'910599','Measurement Standards and Calibration Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (813,'919901','Carbon and Emissions Trading');
INSERT INTO crams_seocode (id, code, description) VALUES (814,'919902','Ecological Economics');
INSERT INTO crams_seocode (id, code, description) VALUES (815,'919999','Economic Framework not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (816,'920101','Blood Disorders');
INSERT INTO crams_seocode (id, code, description) VALUES (817,'920102','Cancer and Related Disorders');
INSERT INTO crams_seocode (id, code, description) VALUES (818,'920103','Cardiovascular System and Diseases');
INSERT INTO crams_seocode (id, code, description) VALUES (819,'920104','Diabetes');
INSERT INTO crams_seocode (id, code, description) VALUES (820,'920105','Digestive System Disorders');
INSERT INTO crams_seocode (id, code, description) VALUES (821,'920106','Endocrine Organs and Diseases (excl. Diabetes)');
INSERT INTO crams_seocode (id, code, description) VALUES (822,'920107','Hearing, Vision, Speech and Their Disorders');
INSERT INTO crams_seocode (id, code, description) VALUES (823,'920108','Immune System and Allergy');
INSERT INTO crams_seocode (id, code, description) VALUES (824,'920109','Infectious Diseases');
INSERT INTO crams_seocode (id, code, description) VALUES (825,'920111','Nervous System and Disorders');
INSERT INTO crams_seocode (id, code, description) VALUES (826,'920112','Neurodegenerative Disorders Related to Ageing');
INSERT INTO crams_seocode (id, code, description) VALUES (827,'920113','Oro-Dental Disorders');
INSERT INTO crams_seocode (id, code, description) VALUES (828,'920114','Reproductive System and Disorders');
INSERT INTO crams_seocode (id, code, description) VALUES (829,'920115','Respiratory System and Diseases (incl. Asthma)');
INSERT INTO crams_seocode (id, code, description) VALUES (830,'920116','Skeletal System and Disorders (incl. Arthritis)');
INSERT INTO crams_seocode (id, code, description) VALUES (831,'920117','Skin and Related Disorders');
INSERT INTO crams_seocode (id, code, description) VALUES (832,'920118','Surgical Methods and Procedures');
INSERT INTO crams_seocode (id, code, description) VALUES (833,'920119','Urogenital System and Disorders');
INSERT INTO crams_seocode (id, code, description) VALUES (834,'920120','Zoonoses');
INSERT INTO crams_seocode (id, code, description) VALUES (835,'920199','Clinical Health (Organs, Diseases and Abnormal Conditions) not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (836,'920201','Allied Health Therapies (excl. Mental Health Services)');
INSERT INTO crams_seocode (id, code, description) VALUES (837,'920202','Carer Health');
INSERT INTO crams_seocode (id, code, description) VALUES (838,'920203','Diagnostic Methods');
INSERT INTO crams_seocode (id, code, description) VALUES (839,'920204','Evaluation of Health Outcomes');
INSERT INTO crams_seocode (id, code, description) VALUES (840,'920206','Health Inequalities');
INSERT INTO crams_seocode (id, code, description) VALUES (841,'920207','Health Policy Economic Outcomes');
INSERT INTO crams_seocode (id, code, description) VALUES (842,'920208','Health Policy Evaluation');
INSERT INTO crams_seocode (id, code, description) VALUES (843,'920209','Mental Health Services');
INSERT INTO crams_seocode (id, code, description) VALUES (844,'920210','Nursing');
INSERT INTO crams_seocode (id, code, description) VALUES (845,'920211','Palliative Care');
INSERT INTO crams_seocode (id, code, description) VALUES (846,'920299','Health and Support Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (847,'920301','Aboriginal and Torres Strait Islander Health - Determinants of Health');
INSERT INTO crams_seocode (id, code, description) VALUES (848,'920302','Aboriginal and Torres Strait Islander Health - Health Status and Outcomes');
INSERT INTO crams_seocode (id, code, description) VALUES (849,'920303','Aboriginal and Torres Strait Islander Health - Health System Performance (incl. Effectiveness of Interventions)');
INSERT INTO crams_seocode (id, code, description) VALUES (850,'920304','Maori Health - Determinants of Health');
INSERT INTO crams_seocode (id, code, description) VALUES (851,'920305','Maori Health - Health Status and Outcomes');
INSERT INTO crams_seocode (id, code, description) VALUES (852,'920306','Maori Health - Health System Performance (incl. Effectiveness of Interventions)');
INSERT INTO crams_seocode (id, code, description) VALUES (853,'920307','Pacific Peoples Health - Determinants of Health');
INSERT INTO crams_seocode (id, code, description) VALUES (854,'920308','Pacific Peoples Health - Health Status and Outcomes');
INSERT INTO crams_seocode (id, code, description) VALUES (855,'920399','Indigenous Health not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (856,'920401','Behaviour and Health');
INSERT INTO crams_seocode (id, code, description) VALUES (857,'920402','Dental Health');
INSERT INTO crams_seocode (id, code, description) VALUES (858,'920403','Disability and Functional Capacity');
INSERT INTO crams_seocode (id, code, description) VALUES (859,'920404','Disease Distribution and Transmission (incl. Surveillance and Response)');
INSERT INTO crams_seocode (id, code, description) VALUES (860,'920405','Environmental Health');
INSERT INTO crams_seocode (id, code, description) VALUES (861,'920406','Food Safety');
INSERT INTO crams_seocode (id, code, description) VALUES (862,'920407','Health Protection and/or Disaster Response');
INSERT INTO crams_seocode (id, code, description) VALUES (863,'920408','Health Status (e.g. Indicators of Well-Being)');
INSERT INTO crams_seocode (id, code, description) VALUES (864,'920409','Injury Control');
INSERT INTO crams_seocode (id, code, description) VALUES (865,'920410','Mental Health');
INSERT INTO crams_seocode (id, code, description) VALUES (866,'920411','Nutrition');
INSERT INTO crams_seocode (id, code, description) VALUES (867,'920412','Preventive Medicine');
INSERT INTO crams_seocode (id, code, description) VALUES (868,'920413','Social Structure and Health');
INSERT INTO crams_seocode (id, code, description) VALUES (869,'920414','Substance Abuse');
INSERT INTO crams_seocode (id, code, description) VALUES (870,'920501','Child Health');
INSERT INTO crams_seocode (id, code, description) VALUES (871,'920502','Health Related to Ageing');
INSERT INTO crams_seocode (id, code, description) VALUES (872,'920503','Health Related to Specific Ethnic Groups');
INSERT INTO crams_seocode (id, code, description) VALUES (873,'920504','Men''s Health');
INSERT INTO crams_seocode (id, code, description) VALUES (874,'920505','Occupational Health');
INSERT INTO crams_seocode (id, code, description) VALUES (875,'920506','Rural Health');
INSERT INTO crams_seocode (id, code, description) VALUES (876,'920507','Women''s Health');
INSERT INTO crams_seocode (id, code, description) VALUES (877,'920599','Specific Population Health (excl. Indigenous Health) not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (878,'929999','Health not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (879,'930101','Learner and Learning Achievement');
INSERT INTO crams_seocode (id, code, description) VALUES (880,'930102','Learner and Learning Processes');
INSERT INTO crams_seocode (id, code, description) VALUES (881,'930103','Learner Development');
INSERT INTO crams_seocode (id, code, description) VALUES (882,'930104','Moral and Social Development (incl. Affect)');
INSERT INTO crams_seocode (id, code, description) VALUES (883,'930199','Learner and Learning not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (884,'930201','Pedagogy');
INSERT INTO crams_seocode (id, code, description) VALUES (885,'930299','Teaching and Instruction not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (886,'930401','Management and Leadership of Schools/Institutions');
INSERT INTO crams_seocode (id, code, description) VALUES (887,'930499','School/Institution not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (888,'930502','Management of Education and Training Systems');
INSERT INTO crams_seocode (id, code, description) VALUES (889,'940110','Environmental Services');
INSERT INTO crams_seocode (id, code, description) VALUES (890,'940112','Families and Family Services');
INSERT INTO crams_seocode (id, code, description) VALUES (891,'940113','Gender and Sexualities');
INSERT INTO crams_seocode (id, code, description) VALUES (892,'940114','Maori Development and Welfare');
INSERT INTO crams_seocode (id, code, description) VALUES (893,'940115','Pacific Peoples Development and Welfare');
INSERT INTO crams_seocode (id, code, description) VALUES (894,'940117','Structure, Delivery and Financing of Community Services');
INSERT INTO crams_seocode (id, code, description) VALUES (895,'940199','Community Service (excl. Work) not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (896,'940201','Civics and Citizenship');
INSERT INTO crams_seocode (id, code, description) VALUES (897,'940202','Electoral Systems');
INSERT INTO crams_seocode (id, code, description) VALUES (898,'940204','Public Services Policy Advice and Analysis');
INSERT INTO crams_seocode (id, code, description) VALUES (899,'940299','Government and Politics not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (900,'940301','Defence and Security Policy');
INSERT INTO crams_seocode (id, code, description) VALUES (901,'940302','International Aid and Development');
INSERT INTO crams_seocode (id, code, description) VALUES (902,'940304','International Political Economy (excl. International Trade)');
INSERT INTO crams_seocode (id, code, description) VALUES (903,'940399','International Relations not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (904,'940401','Civil Justice');
INSERT INTO crams_seocode (id, code, description) VALUES (905,'940402','Crime Prevention');
INSERT INTO crams_seocode (id, code, description) VALUES (906,'940404','Law Enforcement');
INSERT INTO crams_seocode (id, code, description) VALUES (907,'940405','Law Reform');
INSERT INTO crams_seocode (id, code, description) VALUES (908,'940406','Legal Processes');
INSERT INTO crams_seocode (id, code, description) VALUES (909,'940407','Legislation, Civil and Criminal Codes');
INSERT INTO crams_seocode (id, code, description) VALUES (910,'940499','Justice and the Law not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (911,'940501','Employment Patterns and Change');
INSERT INTO crams_seocode (id, code, description) VALUES (912,'940502','Professions and Professionalisation');
INSERT INTO crams_seocode (id, code, description) VALUES (913,'940503','Time Use, Unpaid Work and Volunteering');
INSERT INTO crams_seocode (id, code, description) VALUES (914,'940505','Workplace Safety');
INSERT INTO crams_seocode (id, code, description) VALUES (915,'940599','Work and Institutional Development not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (916,'949999','Law, Politics and Community Services not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (917,'950101','Music');
INSERT INTO crams_seocode (id, code, description) VALUES (918,'950104','The Creative Arts (incl. Graphics and Craft)');
INSERT INTO crams_seocode (id, code, description) VALUES (919,'950201','Communication Across Languages and Culture');
INSERT INTO crams_seocode (id, code, description) VALUES (920,'950204','The Media');
INSERT INTO crams_seocode (id, code, description) VALUES (921,'950301','Ahuatanga Maori (Maori Tradition)');
INSERT INTO crams_seocode (id, code, description) VALUES (922,'950307','Conserving the Historic Environment');
INSERT INTO crams_seocode (id, code, description) VALUES (923,'950308','Matauranga Maori (Maori Knowledge)');
INSERT INTO crams_seocode (id, code, description) VALUES (924,'950309','Taonga (Maori Artefacts)');
INSERT INTO crams_seocode (id, code, description) VALUES (925,'950310','Tikanga Maori (Maori Customary Practices)');
INSERT INTO crams_seocode (id, code, description) VALUES (926,'950311','Wahi Taonga (Maori Places of Significance)');
INSERT INTO crams_seocode (id, code, description) VALUES (927,'950399','Heritage not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (928,'950401','Bioethics');
INSERT INTO crams_seocode (id, code, description) VALUES (929,'950406','Religious Traditions (excl. Structures and Rituals)');
INSERT INTO crams_seocode (id, code, description) VALUES (930,'950501','Understanding Africa''s Past');
INSERT INTO crams_seocode (id, code, description) VALUES (931,'950502','Understanding Asia''s Past');
INSERT INTO crams_seocode (id, code, description) VALUES (932,'950503','Understanding Australia''s Past');
INSERT INTO crams_seocode (id, code, description) VALUES (933,'950505','Understanding New Zealand''s Past');
INSERT INTO crams_seocode (id, code, description) VALUES (934,'950506','Understanding the Past of the Americas');
INSERT INTO crams_seocode (id, code, description) VALUES (935,'950599','Understanding Past Societies not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (936,'960101','Antarctic and Sub-Antarctic Air Quality');
INSERT INTO crams_seocode (id, code, description) VALUES (937,'960102','Coastal and Estuarine Air Quality');
INSERT INTO crams_seocode (id, code, description) VALUES (938,'960103','Farmland, Arable Cropland and Permanent Cropland Air Quality');
INSERT INTO crams_seocode (id, code, description) VALUES (939,'960105','Mining Air Quality');
INSERT INTO crams_seocode (id, code, description) VALUES (940,'960106','Urban and Industrial Air Quality');
INSERT INTO crams_seocode (id, code, description) VALUES (941,'960199','Air Quality not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (942,'960202','Atmospheric Processes and Dynamics');
INSERT INTO crams_seocode (id, code, description) VALUES (943,'960203','Weather');
INSERT INTO crams_seocode (id, code, description) VALUES (944,'960299','Atmosphere and Weather not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (945,'960302','Climate Change Mitigation Strategies');
INSERT INTO crams_seocode (id, code, description) VALUES (946,'960303','Climate Change Models');
INSERT INTO crams_seocode (id, code, description) VALUES (947,'960304','Climate Variability (excl. Social Impacts)');
INSERT INTO crams_seocode (id, code, description) VALUES (948,'960306','Effects of Climate Change and Variability on Antarctic and Sub-Antarctic Environments (excl. Social Impacts)');
INSERT INTO crams_seocode (id, code, description) VALUES (949,'960307','Effects of Climate Change and Variability on Australia (excl. Social Impacts)');
INSERT INTO crams_seocode (id, code, description) VALUES (950,'960308','Effects of Climate Change and Variability on New Zealand (excl. Social Impacts)');
INSERT INTO crams_seocode (id, code, description) VALUES (951,'960401','Border Biosecurity (incl. Quarantine and Inspection)');
INSERT INTO crams_seocode (id, code, description) VALUES (952,'960604','Environmental Management Systems');
INSERT INTO crams_seocode (id, code, description) VALUES (953,'960605','Institutional Arrangements for Environmental Protection');
INSERT INTO crams_seocode (id, code, description) VALUES (954,'960702','Consumption Patterns, Population Issues and the Environment');
INSERT INTO crams_seocode (id, code, description) VALUES (955,'960704','Land Stewardship');
INSERT INTO crams_seocode (id, code, description) VALUES (956,'960806','Forest and Woodlands Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (957,'960807','Fresh, Ground and Surface Water Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (958,'960808','Marine Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (959,'960809','Mining Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (960,'960810','Mountain and High Country Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (961,'960812','Urban and Industrial Flora, Fauna and Biodiversity');
INSERT INTO crams_seocode (id, code, description) VALUES (962,'960899','Flora, Fauna and Biodiversity of Environments not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (963,'960901','Antarctic and Sub-Antarctic Land and Water Management');
INSERT INTO crams_seocode (id, code, description) VALUES (964,'960902','Coastal and Estuarine Land Management');
INSERT INTO crams_seocode (id, code, description) VALUES (965,'960903','Coastal and Estuarine Water Management');
INSERT INTO crams_seocode (id, code, description) VALUES (966,'960905','Farmland, Arable Cropland and Permanent Cropland Water Management');
INSERT INTO crams_seocode (id, code, description) VALUES (967,'960906','Forest and Woodlands Land Management');
INSERT INTO crams_seocode (id, code, description) VALUES (968,'960907','Forest and Woodlands Water Management');
INSERT INTO crams_seocode (id, code, description) VALUES (969,'960908','Mining Land and Water Management');
INSERT INTO crams_seocode (id, code, description) VALUES (970,'960909','Mountain and High Country Land and Water Management');
INSERT INTO crams_seocode (id, code, description) VALUES (971,'960911','Urban and Industrial Land Management');
INSERT INTO crams_seocode (id, code, description) VALUES (972,'960912','Urban and Industrial Water Management');
INSERT INTO crams_seocode (id, code, description) VALUES (973,'960913','Water Allocation and Quantification');
INSERT INTO crams_seocode (id, code, description) VALUES (974,'960999','Land and Water Management of Environments not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (975,'961001','Natural Hazards in Antarctic and Sub-Antarctic Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (976,'961003','Natural Hazards in Farmland, Arable Cropland and Permanent Cropland Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (977,'961004','Natural Hazards in Forest and Woodlands Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (978,'961005','Natural Hazards in Fresh, Ground and Surface Water Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (979,'961006','Natural Hazards in Marine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (980,'961007','Natural Hazards in Mining Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (981,'961009','Natural Hazards in Sparseland, Permanent Grassland and Arid Zone Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (982,'961010','Natural Hazards in Urban and Industrial Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (983,'961099','Natural Hazards not elsewhere classified');
INSERT INTO crams_seocode (id, code, description) VALUES (984,'961101','Physical and Chemical Conditions of Water for Urban and Industrial Use');
INSERT INTO crams_seocode (id, code, description) VALUES (985,'961102','Physical and Chemical Conditions of Water in Coastal and Estuarine Environments');
INSERT INTO crams_seocode (id, code, description) VALUES (999996,'999996','HPC Data Migration');
INSERT INTO crams_seocode (id, code, description) VALUES (999997,'999997','HPC Internal Operations');