# Generated by Django 3.2.4 on 2021-07-21 01:19

from django.db import migrations, models

def load_software_status_sql():
    import os

    file_name = 'software_status.sql'
    sql_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '../sqls'))
    sql_statements = open(os.path.join(sql_dir, file_name), 'r').read()

    return sql_statements

class Migration(migrations.Migration):

    dependencies = [
        ('crams', '0010_projectmemberstatus_lookups'),
    ]

    operations = [
        migrations.CreateModel(
            name='SoftwareLicenseStatus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.CharField(max_length=50)),
                ('status', models.CharField(max_length=100)),
            ],
        ),
        migrations.RunSQL(load_software_status_sql()),
    ]
