# Generated by Django 3.1.1 on 2021-03-08 06:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('crams', '0006_cramstoken'),
    ]

    operations = [
        migrations.CreateModel(
            name='CostUnitType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('unit_name', models.CharField(max_length=19)),
            ],
        ),
        migrations.CreateModel(
            name='Zone',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64)),
                ('description', models.TextField()),
            ],
        ),
    ]
