# coding=utf-8
"""
API Constants
"""
REQUEST_PARAM_DRAFT = 'draft'
CLONE = 'clone'

# Serializer Override
OVERRIDE_READONLY_DATA = 'OVERRIDE_READONLY'
DO_NOT_OVERRIDE_PROVISION_DETAILS = 'DO_NOT_OVERRIDE_PROVISION_DETAILS'
