INSERT INTO crams_duration (id, duration, duration_label) VALUES (1, 1, '1-month');
INSERT INTO crams_duration (id, duration, duration_label) VALUES (2, 3, '3-months');
INSERT INTO crams_duration (id, duration, duration_label) VALUES (3, 6, '6-months');
INSERT INTO crams_duration (id, duration, duration_label) VALUES (4, 12, '12-months');