# Generated by Django 3.1.1 on 2020-09-25 02:22

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crams', '0001_auth'),
    ]

    operations = [
        migrations.CreateModel(
            name='EResearchBody',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=200)),
                ('email', models.EmailField(blank=True, max_length=254, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='EResearchBodySystem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=200)),
                ('email', models.EmailField(blank=True, max_length=254, null=True)),
                ('e_research_body', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='systems', to='crams.eresearchbody')),
            ],
            options={
                'unique_together': {('name', 'e_research_body')},
                'index_together': {('name', 'e_research_body')},
            },
        ),
        migrations.CreateModel(
            name='EResearchBodyIDKey',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(choices=[('I', 'Id_Key'), ('L', 'Label'), ('M', 'Metadata')], default='I', max_length=1)),
                ('key', models.CharField(max_length=100)),
                ('description', models.TextField(blank=True, null=True)),
                ('e_research_body', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='crams.eresearchbody')),
            ],
            options={
                'unique_together': {('key', 'e_research_body')},
            },
        ),
        migrations.CreateModel(
            name='EResearchBodyDelegate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=200)),
                ('email', models.EmailField(blank=True, max_length=254, null=True)),
                ('e_research_body', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='delegates', to='crams.eresearchbody')),
            ],
            options={
                'unique_together': {('name', 'e_research_body')},
                'index_together': {('name', 'e_research_body')},
            },
        ),
    ]
