# Generated by Django 3.1.1 on 2020-09-25 02:31

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crams', '0004_provider'),
    ]

    operations = [
        migrations.CreateModel(
            name='SupportEmailContact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(blank=True, max_length=255, null=True)),
                ('email', models.EmailField(db_index=True, max_length=254)),
                ('e_research_body', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='crams.eresearchbody')),
                ('e_research_system', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='crams.eresearchbodysystem')),
            ],
        ),
        migrations.CreateModel(
            name='MessageOfTheDay',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('creation_ts', models.DateTimeField(auto_now_add=True)),
                ('last_modified_ts', models.DateTimeField(auto_now=True)),
                ('message', models.CharField(blank=True, max_length=1500, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='messageoftheday_created_by', to=settings.AUTH_USER_MODEL)),
                ('e_research_body', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='crams.eresearchbody')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='messageoftheday_updated_by', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
